@@ -373,7 +373,7 @@ def command_init(options):
     except urllib2.URLError as e:
         print("ERROR: cannot download default sources list from:\n%s\nWebsite may be down."%(DEFAULT_SOURCES_LIST_URL))
         return 4
-    # reuse path variable for error message
+    # reuse path variable for error message 
     path = get_sources_list_dir()
     try:
         if not os.path.exists(path):
@@ -394,11 +394,19 @@ def command_init(options):
         return 3
     
 def command_update(options):
+    error_occured = []
     def update_success_handler(data_source):
         print("Hit %s"%(data_source.url))
     def update_error_handler(data_source, exc):
-        print("ERROR: unable to process source [%s]:\n\t%s"%(data_source.url, exc), file=sys.stderr)
+        error_string = "ERROR: unable to process source [%s]:\n\t%s"%(data_source.url, exc)
+        print(error_string, file=sys.stderr)
+        error_occured.append(error_string)
     sources_list_dir = get_sources_list_dir()
+
+    if not os.path.exists(sources_list_dir):
+        print("ERROR: no sources directory exists on the system meaning rosdep has not yet been initialized.\n\nPlease initialize your rosdep with\n\n\tsudo rosdep init\n")
+        return 1
+
     filelist = [f for f in os.listdir(sources_list_dir) if f.endswith('.list')]    
     if not filelist:
         print("ERROR: no data sources in %s\n\nPlease initialize your rosdep with\n\n\tsudo rosdep init\n"%sources_list_dir, file=sys.stderr)
@@ -410,8 +418,17 @@ def command_update(options):
         print("updated cache in %s"%(get_sources_cache_dir()))
     except InvalidData as e:
         print("ERROR: invalid sources list file:\n\t%s"%(e), file=sys.stderr)
+        return 1
     except IOError as e:
         print("ERROR: error loading sources list:\n\t%s"%(e), file=sys.stderr)
+        return 1
+    if error_occured:
+        print ("ERROR: Not all sources were able to be updated.\n[[[")
+        for e in error_occured:
+            print (e)
+        print("]]]")
+        return 1
+
     
 def command_keys(lookup, packages, options):
     lookup = _get_default_RosdepLookup(options)
